Documentation
¶
Index ¶
- Constants
- func SetUserAgent(ua string)
- type ACLRoleCollection
- type ACLUserRoleCollection
- type APIContext
- type APIError
- type AppActionButtonCollection
- type AppActionButtonTranslationCollection
- type AppCmsBlockCollection
- type AppCmsBlockTranslationCollection
- type AppCollection
- type AppPaymentMethodCollection
- type AppTemplateCollection
- type AppTranslationCollection
- type CategoryCollection
- type CategoryTagCollection
- type CategoryTranslationCollection
- type Client
- func (c *Client) BareDo(ctx context.Context, req *http.Request) (*http.Response, error)
- func (c Client) Clear(ctx APIContext) (*http.Response, error)
- func (c *Client) Delete(ctx APIContext, entity interface{}, ids []string) (*http.Response, error)
- func (c *Client) Do(ctx context.Context, req *http.Request, v interface{}) (*http.Response, error)
- func (c *Client) GetSegment(v interface{}) string
- func (c *Client) GetSegmentSnakeCase(v interface{}) string
- func (c *Client) Info(ctx APIContext) (*InfoResponse, *http.Response, error)
- func (c *Client) NewRawRequest(context APIContext, method, path string, options map[string]string, ...) (*http.Request, error)
- func (c *Client) NewRequest(context APIContext, method, path string, options map[string]string, ...) (*http.Request, error)
- func (c *Client) Search(ctx APIContext, criteria Criteria, v Collection) error
- func (c *Client) SearchAll(ctx APIContext, criteria Criteria, v Collection) error
- func (c *Client) SearchIDs(ctx APIContext, criteria Criteria, v interface{}) (*SearchIDsResponse, error)
- func (c *Client) Sync(ctx APIContext, payload map[string]SyncOperation) (*http.Response, error)
- func (c *Client) Upsert(ctx APIContext, entities interface{}) (*http.Response, error)
- type CmsBlockCollection
- type CmsPageCollection
- type CmsPageTranslationCollection
- type CmsSectionCollection
- type CmsSlotCollection
- type CmsSlotTranslationCollection
- type Collection
- type CountryCollection
- type CountryStateCollection
- type CountryStateTranslationCollection
- type CountryTranslationCollection
- type Criteria
- type CriteriaFilter
- type CriteriaFilterQuery
- type CriteriaQuery
- type CriteriaSort
- type CurrencyCollection
- type CurrencyCountryRoundingCollection
- type CurrencyTranslationCollection
- type CustomFieldCollection
- type CustomFieldSetCollection
- type CustomFieldSetRelationCollection
- type CustomPriceCollection
- type CustomerAddressCollection
- type CustomerCollection
- type CustomerGroupCollection
- type CustomerGroupRegistrationSalesChannelsCollection
- type CustomerGroupTranslationCollection
- type CustomerRecoveryCollection
- type CustomerTagCollection
- type CustomerWishlistCollection
- type CustomerWishlistProductCollection
- type DeadMessageCollection
- type DeliveryTimeCollection
- type DeliveryTimeTranslationCollection
- type DocumentBaseConfigCollection
- type DocumentBaseConfigSalesChannelCollection
- type DocumentCollection
- type DocumentTypeCollection
- type DocumentTypeTranslationCollection
- type EntityCollection
- type ErrorResponse
- type EventActionCollection
- type EventActionRuleCollection
- type EventActionSalesChannelCollection
- type FlowCollection
- type FlowSequenceCollection
- type ImportExportFileCollection
- type ImportExportLogCollection
- type ImportExportProfileCollection
- type ImportExportProfileTranslationCollection
- type InfoResponse
- type IntegrationCollection
- type IntegrationCredentials
- type IntegrationRoleCollection
- type LandingPageCollection
- type LandingPageSalesChannelCollection
- type LandingPageTagCollection
- type LandingPageTranslationCollection
- type LanguageCollection
- type LocaleCollection
- type LocaleTranslationCollection
- type LogEntryCollection
- type MailHeaderFooterCollection
- type MailHeaderFooterTranslationCollection
- type MailTemplateCollection
- type MailTemplateMediaCollection
- type MailTemplateTranslationCollection
- type MailTemplateTypeCollection
- type MailTemplateTypeTranslationCollection
- type MainCategoryCollection
- type MediaCollection
- type MediaDefaultFolderCollection
- type MediaFolderCollection
- type MediaFolderConfigurationCollection
- type MediaFolderConfigurationMediaThumbnailSizeCollection
- type MediaTagCollection
- type MediaThumbnailCollection
- type MediaThumbnailSizeCollection
- type MediaTranslationCollection
- type MessageQueueStatsCollection
- type NewsletterRecipientCollection
- type NewsletterRecipientTagCollection
- type NotificationCollection
- type NumberRangeCollection
- type NumberRangeSalesChannelCollection
- type NumberRangeStateCollection
- type NumberRangeTranslationCollection
- type NumberRangeTypeCollection
- type NumberRangeTypeTranslationCollection
- type OAuthCredentials
- type OrderAddressCollection
- type OrderCollection
- type OrderCustomerCollection
- type OrderDeliveryCollection
- type OrderDeliveryPositionCollection
- type OrderLineItemCollection
- type OrderTagCollection
- type OrderTransactionCollection
- type PasswordCredentials
- type PaymentMethodCollection
- type PaymentMethodTranslationCollection
- type PluginCollection
- type PluginTranslationCollection
- type ProductCategoryCollection
- type ProductCategoryTreeCollection
- type ProductCollection
- type ProductConfiguratorSettingCollection
- type ProductCrossSellingAssignedProductsCollection
- type ProductCrossSellingCollection
- type ProductCrossSellingTranslationCollection
- type ProductCustomFieldSetCollection
- type ProductExportCollection
- type ProductFeatureSetCollection
- type ProductFeatureSetTranslationCollection
- type ProductKeywordDictionaryCollection
- type ProductManufacturerCollection
- type ProductManufacturerTranslationCollection
- type ProductMediaCollection
- type ProductOptionCollection
- type ProductPriceCollection
- type ProductPropertyCollection
- type ProductReviewCollection
- type ProductSearchConfigCollection
- type ProductSearchConfigFieldCollection
- type ProductSearchKeywordCollection
- type ProductSortingCollection
- type ProductSortingTranslationCollection
- type ProductStreamCollection
- type ProductStreamFilterCollection
- type ProductStreamMappingCollection
- type ProductStreamTranslationCollection
- type ProductTagCollection
- type ProductTranslationCollection
- type ProductVisibilityCollection
- type PromotionCartRuleCollection
- type PromotionCollection
- type PromotionDiscountCollection
- type PromotionDiscountPricesCollection
- type PromotionDiscountRuleCollection
- type PromotionIndividualCodeCollection
- type PromotionOrderRuleCollection
- type PromotionPersonaCustomerCollection
- type PromotionPersonaRuleCollection
- type PromotionSalesChannelCollection
- type PromotionSetgroupCollection
- type PromotionSetgroupRuleCollection
- type PromotionTranslationCollection
- type PropertyGroupCollection
- type PropertyGroupOptionCollection
- type PropertyGroupOptionTranslationCollection
- type PropertyGroupTranslationCollection
- type RuleCollection
- type RuleConditionCollection
- type RuleTagCollection
- type SEOUrlCollection
- type SEOUrlTemplateCollection
- type SalesChannelAnalyticsCollection
- type SalesChannelCollection
- type SalesChannelCountryCollection
- type SalesChannelCurrencyCollection
- type SalesChannelDomainCollection
- type SalesChannelLanguageCollection
- type SalesChannelPaymentMethodCollection
- type SalesChannelShippingMethodCollection
- type SalesChannelTranslationCollection
- type SalesChannelTypeCollection
- type SalesChannelTypeTranslationCollection
- type SalutationCollection
- type SalutationTranslationCollection
- type ScheduledTaskCollection
- type ScriptCollection
- type SearchFilterType
- type SearchIDsResponse
- type SearchSortDirection
- type ShippingMethodCollection
- type ShippingMethodPriceCollection
- type ShippingMethodTagCollection
- type ShippingMethodTranslationCollection
- type SnippetCollection
- type SnippetSetCollection
- type StateMachineCollection
- type StateMachineHistoryCollection
- type StateMachineStateCollection
- type StateMachineStateTranslationCollection
- type StateMachineTransitionCollection
- type StateMachineTranslationCollection
- type SyncOperation
- type SystemConfigCollection
- type TagCollection
- type TaxCollection
- type TaxRuleCollection
- type TaxRuleTypeCollection
- type TaxRuleTypeTranslationCollection
- type ThemeChildCollection
- type ThemeCollection
- type ThemeMediaCollection
- type ThemeSalesChannelCollection
- type ThemeTranslationCollection
- type TotalCountMode
- type UnitCollection
- type UnitTranslationCollection
- type UserAccessKeyCollection
- type UserCollection
- type UserConfigCollection
- type UserRecoveryCollection
- type VersionCollection
- type VersionCommitCollection
- type VersionCommitDataCollection
- type WebhookCollection
- type WebhookEventLogCollection
Constants ¶
const ( TotalCountModeDefault = 1 TotalCountModeExact = 2 TotalCountModeNextPage = 3 SearchFilterTypeEquals = "equals" SearchFilterTypeEqualsAny = "equalsAny" SearchFilterTypeContains = "contains" SearchFilterTypeRange = "range" SearchFilterTypeNot = "not" SearchFilterTypeMulti = "multi" SearchFilterTypePrefix = "prefix" SearchFilterTypeSuffix = "suffix" SearchSortDirectionAscending = "ASC" SearchSortDirectionDescending = "DESC" )
Variables ¶
This section is empty.
Functions ¶
func SetUserAgent ¶ added in v1.2.7
func SetUserAgent(ua string)
Types ¶
type ACLRoleCollection ¶ added in v1.1.0
type ACLRoleCollection struct {
EntityCollection
Data []model.AclRole `json:"data"`
}
type ACLUserRoleCollection ¶ added in v1.1.0
type ACLUserRoleCollection struct {
EntityCollection
Data []model.AclUserRole `json:"data"`
}
type APIContext ¶ added in v1.1.0
APIContext is the context for the api requests
func NewAPIContext ¶ added in v1.1.0
func NewAPIContext(ctx context.Context) APIContext
NewAPIContext creates a new ApiContext with the given context and default values
type APIError ¶
type APIError struct {
StatusCode int
Response ErrorResponse
Raw []byte
}
type AppActionButtonCollection ¶
type AppActionButtonCollection struct {
EntityCollection
Data []model.AppActionButton `json:"data"`
}
type AppActionButtonTranslationCollection ¶
type AppActionButtonTranslationCollection struct {
EntityCollection
Data []model.AppActionButtonTranslation `json:"data"`
}
type AppCmsBlockCollection ¶
type AppCmsBlockCollection struct {
EntityCollection
Data []model.AppCmsBlock `json:"data"`
}
type AppCmsBlockTranslationCollection ¶
type AppCmsBlockTranslationCollection struct {
EntityCollection
Data []model.AppCmsBlockTranslation `json:"data"`
}
type AppCollection ¶
type AppCollection struct {
EntityCollection
Data []model.App `json:"data"`
}
type AppPaymentMethodCollection ¶
type AppPaymentMethodCollection struct {
EntityCollection
Data []model.AppPaymentMethod `json:"data"`
}
type AppTemplateCollection ¶
type AppTemplateCollection struct {
EntityCollection
Data []model.AppTemplate `json:"data"`
}
type AppTranslationCollection ¶
type AppTranslationCollection struct {
EntityCollection
Data []model.AppTranslation `json:"data"`
}
type CategoryCollection ¶
type CategoryCollection struct {
EntityCollection
Data []model.Category `json:"data"`
}
type CategoryTagCollection ¶
type CategoryTagCollection struct {
EntityCollection
Data []model.CategoryTag `json:"data"`
}
type CategoryTranslationCollection ¶
type CategoryTranslationCollection struct {
EntityCollection
Data []model.CategoryTranslation `json:"data"`
}
type Client ¶
type Client struct {
ResponseHandler func(resp *http.Response) error
// contains filtered or unexported fields
}
Client is the main client struct for the shopware api communication
func NewClient ¶
func NewClient(ctx context.Context, shopURL string, credentials OAuthCredentials, httpClient *http.Client) (*Client, error)
NewClient creates a new client for the shopware api
func (Client) Clear ¶
func (c Client) Clear(ctx APIContext) (*http.Response, error)
Clear the shopware cache
func (*Client) Delete ¶
Deletes the provided entities in bulk mode Uses underlying Sync method to perform the request
func (*Client) GetSegment ¶
Returns the segment of the path that is used to identify the resource. This is the same as the name of the struct that is used to represent the resource but
func (*Client) GetSegmentSnakeCase ¶
func (*Client) Info ¶
func (c *Client) Info(ctx APIContext) (*InfoResponse, *http.Response, error)
Info returns the info of the shopware api
func (*Client) NewRawRequest ¶
func (c *Client) NewRawRequest(context APIContext, method, path string, options map[string]string, body io.Reader) (*http.Request, error)
Creates a new request using a io.Reader as body and without encoding the body as json This has to be done manually by the caller if needed
func (*Client) NewRequest ¶
func (c *Client) NewRequest(context APIContext, method, path string, options map[string]string, body interface{}) (*http.Request, error)
Creates a new request with the given context, method, url and body The body will be encoded as json and the content type will be set to application/json
func (*Client) Search ¶
func (c *Client) Search(ctx APIContext, criteria Criteria, v Collection) error
Search performs a search request for the given criteria and collection The collection must be a pointer to a struct that implements the Collection interface
func (*Client) SearchAll ¶
func (c *Client) SearchAll(ctx APIContext, criteria Criteria, v Collection) error
SearchAll performs multiple search requests with a limited size until all results are fetched
func (*Client) SearchIDs ¶ added in v1.1.0
func (c *Client) SearchIDs(ctx APIContext, criteria Criteria, v interface{}) (*SearchIDsResponse, error)
SearchIDs performs a search request for the given criteria and returns only the ids
func (*Client) Sync ¶
func (c *Client) Sync(ctx APIContext, payload map[string]SyncOperation) (*http.Response, error)
Starts a sync process for the list of provided actions. This can be inserts, upserts, updates and deletes on different entities.
type CmsBlockCollection ¶
type CmsBlockCollection struct {
EntityCollection
Data []model.CmsBlock `json:"data"`
}
type CmsPageCollection ¶
type CmsPageCollection struct {
EntityCollection
Data []model.CmsPage `json:"data"`
}
type CmsPageTranslationCollection ¶
type CmsPageTranslationCollection struct {
EntityCollection
Data []model.CmsPageTranslation `json:"data"`
}
type CmsSectionCollection ¶
type CmsSectionCollection struct {
EntityCollection
Data []model.CmsSection `json:"data"`
}
type CmsSlotCollection ¶
type CmsSlotCollection struct {
EntityCollection
Data []model.CmsSlot `json:"data"`
}
type CmsSlotTranslationCollection ¶
type CmsSlotTranslationCollection struct {
EntityCollection
Data []model.CmsSlotTranslation `json:"data"`
}
type Collection ¶
type Collection interface {
// contains filtered or unexported methods
}
Collection is the interface for all collections returned by the shopware api Implemented by EntityCollection which in turn is embedded by all other collections.
type CountryCollection ¶
type CountryCollection struct {
EntityCollection
Data []model.Country `json:"data"`
}
type CountryStateCollection ¶
type CountryStateCollection struct {
EntityCollection
Data []model.CountryState `json:"data"`
}
type CountryStateTranslationCollection ¶
type CountryStateTranslationCollection struct {
EntityCollection
Data []model.CountryStateTranslation `json:"data"`
}
type CountryTranslationCollection ¶
type CountryTranslationCollection struct {
EntityCollection
Data []model.CountryTranslation `json:"data"`
}
type Criteria ¶
type Criteria struct {
Includes map[string][]string `json:"includes,omitempty"`
Page int64 `json:"page,omitempty"`
Limit int64 `json:"limit,omitempty"`
IDs []string `json:"ids,omitempty"`
Filter []interface{} `json:"filter,omitempty"`
PostFilter []interface{} `json:"postFilter,omitempty"`
Sort []CriteriaSort `json:"sort,omitempty"`
Associations map[string]Criteria `json:"associations,omitempty"`
Term string `json:"term,omitempty"`
TotalCountMode int `json:"totalCountMode,omitempty"`
Query []CriteriaQuery `json:"query,omitempty"`
}
Criteria is the struct that sums up all the search criteria.
type CriteriaFilter ¶
type CriteriaFilter struct {
Type string `json:"type"`
Operator string `json:"operator,omitempty"`
Queries []interface{} `json:"queries,omitempty"`
}
CriteriaFilter is the struct that defines a filter to be applied when searching.
type CriteriaFilterQuery ¶ added in v1.2.0
type CriteriaFilterQuery struct {
CriteriaFilter
Field string `json:"field"`
Value interface{} `json:"value"`
}
CriteriaFilterQuery is an extension of the CriteriaFilter struct that includes the field and value to be filtered.
type CriteriaQuery ¶ added in v1.2.0
type CriteriaQuery struct {
Score uint64 `json:"score"`
Query CriteriaFilterQuery `json:"query"`
}
CriteriaQuery is a struct that defines queries and a score to be applied when searching.
type CriteriaSort ¶
type CriteriaSort struct {
Direction string `json:"order"`
Field string `json:"field"`
NaturalSorting bool `json:"naturalSorting"`
}
CriteriaSort is the struct that defines a sort to be applied when searching.
type CurrencyCollection ¶
type CurrencyCollection struct {
EntityCollection
Data []model.Currency `json:"data"`
}
type CurrencyCountryRoundingCollection ¶
type CurrencyCountryRoundingCollection struct {
EntityCollection
Data []model.CurrencyCountryRounding `json:"data"`
}
type CurrencyTranslationCollection ¶
type CurrencyTranslationCollection struct {
EntityCollection
Data []model.CurrencyTranslation `json:"data"`
}
type CustomFieldCollection ¶
type CustomFieldCollection struct {
EntityCollection
Data []model.CustomField `json:"data"`
}
type CustomFieldSetCollection ¶
type CustomFieldSetCollection struct {
EntityCollection
Data []model.CustomFieldSet `json:"data"`
}
type CustomFieldSetRelationCollection ¶
type CustomFieldSetRelationCollection struct {
EntityCollection
Data []model.CustomFieldSetRelation `json:"data"`
}
type CustomPriceCollection ¶
type CustomPriceCollection struct {
EntityCollection
Data []model.CustomPrice `json:"data"`
}
type CustomerAddressCollection ¶
type CustomerAddressCollection struct {
EntityCollection
Data []model.CustomerAddress `json:"data"`
}
type CustomerCollection ¶
type CustomerCollection struct {
EntityCollection
Data []model.Customer `json:"data"`
}
type CustomerGroupCollection ¶
type CustomerGroupCollection struct {
EntityCollection
Data []model.CustomerGroup `json:"data"`
}
type CustomerGroupRegistrationSalesChannelsCollection ¶
type CustomerGroupRegistrationSalesChannelsCollection struct {
EntityCollection
Data []model.CustomerGroupRegistrationSalesChannels `json:"data"`
}
type CustomerGroupTranslationCollection ¶
type CustomerGroupTranslationCollection struct {
EntityCollection
Data []model.CustomerGroupTranslation `json:"data"`
}
type CustomerRecoveryCollection ¶
type CustomerRecoveryCollection struct {
EntityCollection
Data []model.CustomerRecovery `json:"data"`
}
type CustomerTagCollection ¶
type CustomerTagCollection struct {
EntityCollection
Data []model.CustomerTag `json:"data"`
}
type CustomerWishlistCollection ¶
type CustomerWishlistCollection struct {
EntityCollection
Data []model.CustomerWishlist `json:"data"`
}
type CustomerWishlistProductCollection ¶
type CustomerWishlistProductCollection struct {
EntityCollection
Data []model.CustomerWishlistProduct `json:"data"`
}
type DeadMessageCollection ¶
type DeadMessageCollection struct {
EntityCollection
Data []model.DeadMessage `json:"data"`
}
type DeliveryTimeCollection ¶
type DeliveryTimeCollection struct {
EntityCollection
Data []model.DeliveryTime `json:"data"`
}
type DeliveryTimeTranslationCollection ¶
type DeliveryTimeTranslationCollection struct {
EntityCollection
Data []model.DeliveryTimeTranslation `json:"data"`
}
type DocumentBaseConfigCollection ¶
type DocumentBaseConfigCollection struct {
EntityCollection
Data []model.DocumentBaseConfig `json:"data"`
}
type DocumentBaseConfigSalesChannelCollection ¶
type DocumentBaseConfigSalesChannelCollection struct {
EntityCollection
Data []model.DocumentBaseConfigSalesChannel `json:"data"`
}
type DocumentCollection ¶
type DocumentCollection struct {
EntityCollection
Data []model.Document `json:"data"`
}
type DocumentTypeCollection ¶
type DocumentTypeCollection struct {
EntityCollection
Data []model.DocumentType `json:"data"`
}
type DocumentTypeTranslationCollection ¶
type DocumentTypeTranslationCollection struct {
EntityCollection
Data []model.DocumentTypeTranslation `json:"data"`
}
type EntityCollection ¶
type EntityCollection struct {
Total int64 `json:"total"`
Aggregations interface{} `json:"aggregations"`
Data []interface{} `json:"data"`
}
EntityCollection is the base collection for all other collections
type ErrorResponse ¶
type ErrorResponse struct {
Errors []struct {
Status string `json:"status"`
Code string `json:"code"`
Title string `json:"title"`
Detail string `json:"detail"`
Source struct {
Pointer string `json:"pointer"`
} `json:"source"`
Meta struct {
Parameters interface{} `json:"parameters"`
} `json:"meta"`
} `json:"errors"`
Extensions []interface{} `json:"extensions"`
}
type EventActionCollection ¶
type EventActionCollection struct {
EntityCollection
Data []model.EventAction `json:"data"`
}
type EventActionRuleCollection ¶
type EventActionRuleCollection struct {
EntityCollection
Data []model.EventActionRule `json:"data"`
}
type EventActionSalesChannelCollection ¶
type EventActionSalesChannelCollection struct {
EntityCollection
Data []model.EventActionSalesChannel `json:"data"`
}
type FlowCollection ¶
type FlowCollection struct {
EntityCollection
Data []model.Flow `json:"data"`
}
type FlowSequenceCollection ¶
type FlowSequenceCollection struct {
EntityCollection
Data []model.FlowSequence `json:"data"`
}
type ImportExportFileCollection ¶
type ImportExportFileCollection struct {
EntityCollection
Data []model.ImportExportFile `json:"data"`
}
type ImportExportLogCollection ¶
type ImportExportLogCollection struct {
EntityCollection
Data []model.ImportExportLog `json:"data"`
}
type ImportExportProfileCollection ¶
type ImportExportProfileCollection struct {
EntityCollection
Data []model.ImportExportProfile `json:"data"`
}
type ImportExportProfileTranslationCollection ¶
type ImportExportProfileTranslationCollection struct {
EntityCollection
Data []model.ImportExportProfileTranslation `json:"data"`
}
type InfoResponse ¶
type InfoResponse struct {
Version string `json:"version"`
VersionRevision string `json:"versionRevision"`
AdminWorker struct {
EnableAdminWorker bool `json:"enableAdminWorker"`
Transports []string `json:"transports"`
} `json:"adminWorker"`
Bundles map[string]infoResponseBundle `json:"bundles"`
Settings struct {
EnableURLFeature bool `json:"enableUrlFeature"`
} `json:"settings"`
}
InfoResponse is the response of the info request to the shopware api
func (InfoResponse) IsCloudShop ¶
func (r InfoResponse) IsCloudShop() bool
IsCloudShop checks if the shop is a cloud shop
type IntegrationCollection ¶
type IntegrationCollection struct {
EntityCollection
Data []model.Integration `json:"data"`
}
type IntegrationCredentials ¶
IntegrationCredentials are the credentials for the authorization using a API key
func NewIntegrationCredentials ¶
func NewIntegrationCredentials(clientID, clientSecret string, scopes []string) IntegrationCredentials
NewIntegrationCredentials creates a new IntegrationCredentials struct with the given parameters
func (IntegrationCredentials) GetTokenSource ¶
func (c IntegrationCredentials) GetTokenSource(ctx context.Context, tokenURL string) (oauth2.TokenSource, error)
GetTokenSource returns the token source for the client credentials grant type
type IntegrationRoleCollection ¶
type IntegrationRoleCollection struct {
EntityCollection
Data []model.IntegrationRole `json:"data"`
}
type LandingPageCollection ¶
type LandingPageCollection struct {
EntityCollection
Data []model.LandingPage `json:"data"`
}
type LandingPageSalesChannelCollection ¶
type LandingPageSalesChannelCollection struct {
EntityCollection
Data []model.LandingPageSalesChannel `json:"data"`
}
type LandingPageTagCollection ¶
type LandingPageTagCollection struct {
EntityCollection
Data []model.LandingPageTag `json:"data"`
}
type LandingPageTranslationCollection ¶
type LandingPageTranslationCollection struct {
EntityCollection
Data []model.LandingPageTranslation `json:"data"`
}
type LanguageCollection ¶
type LanguageCollection struct {
EntityCollection
Data []model.Language `json:"data"`
}
type LocaleCollection ¶
type LocaleCollection struct {
EntityCollection
Data []model.Locale `json:"data"`
}
type LocaleTranslationCollection ¶
type LocaleTranslationCollection struct {
EntityCollection
Data []model.LocaleTranslation `json:"data"`
}
type LogEntryCollection ¶
type LogEntryCollection struct {
EntityCollection
Data []model.LogEntry `json:"data"`
}
type MailHeaderFooterCollection ¶
type MailHeaderFooterCollection struct {
}
type MailHeaderFooterTranslationCollection ¶
type MailHeaderFooterTranslationCollection struct {
}
type MailTemplateCollection ¶
type MailTemplateCollection struct {
EntityCollection
Data []model.MailTemplate `json:"data"`
}
type MailTemplateMediaCollection ¶
type MailTemplateMediaCollection struct {
EntityCollection
Data []model.MailTemplateMedia `json:"data"`
}
type MailTemplateTranslationCollection ¶
type MailTemplateTranslationCollection struct {
EntityCollection
Data []model.MailTemplateTranslation `json:"data"`
}
type MailTemplateTypeCollection ¶
type MailTemplateTypeCollection struct {
EntityCollection
Data []model.MailTemplateType `json:"data"`
}
type MailTemplateTypeTranslationCollection ¶
type MailTemplateTypeTranslationCollection struct {
EntityCollection
Data []model.MailTemplateTypeTranslation `json:"data"`
}
type MainCategoryCollection ¶
type MainCategoryCollection struct {
EntityCollection
Data []model.MainCategory `json:"data"`
}
type MediaCollection ¶
type MediaCollection struct {
EntityCollection
Data []model.Media `json:"data"`
}
type MediaDefaultFolderCollection ¶
type MediaDefaultFolderCollection struct {
EntityCollection
Data []model.MediaDefaultFolder `json:"data"`
}
type MediaFolderCollection ¶
type MediaFolderCollection struct {
EntityCollection
Data []model.MediaFolder `json:"data"`
}
type MediaFolderConfigurationCollection ¶
type MediaFolderConfigurationCollection struct {
EntityCollection
Data []model.MediaFolderConfiguration `json:"data"`
}
type MediaFolderConfigurationMediaThumbnailSizeCollection ¶
type MediaFolderConfigurationMediaThumbnailSizeCollection struct {
EntityCollection
Data []model.MediaFolderConfigurationMediaThumbnailSize `json:"data"`
}
type MediaTagCollection ¶
type MediaTagCollection struct {
EntityCollection
Data []model.MediaTag `json:"data"`
}
type MediaThumbnailCollection ¶
type MediaThumbnailCollection struct {
EntityCollection
Data []model.MediaThumbnail `json:"data"`
}
type MediaThumbnailSizeCollection ¶
type MediaThumbnailSizeCollection struct {
EntityCollection
Data []model.MediaThumbnailSize `json:"data"`
}
type MediaTranslationCollection ¶
type MediaTranslationCollection struct {
EntityCollection
Data []model.MediaTranslation `json:"data"`
}
type MessageQueueStatsCollection ¶
type MessageQueueStatsCollection struct {
EntityCollection
Data []model.MessageQueueStats `json:"data"`
}
type NewsletterRecipientCollection ¶
type NewsletterRecipientCollection struct {
EntityCollection
Data []model.NewsletterRecipient `json:"data"`
}
type NewsletterRecipientTagCollection ¶
type NewsletterRecipientTagCollection struct {
EntityCollection
Data []model.NewsletterRecipientTag `json:"data"`
}
type NotificationCollection ¶
type NotificationCollection struct {
EntityCollection
Data []model.Notification `json:"data"`
}
type NumberRangeCollection ¶
type NumberRangeCollection struct {
EntityCollection
Data []model.NumberRange `json:"data"`
}
type NumberRangeSalesChannelCollection ¶
type NumberRangeSalesChannelCollection struct {
EntityCollection
Data []model.NumberRangeSalesChannel `json:"data"`
}
type NumberRangeStateCollection ¶
type NumberRangeStateCollection struct {
EntityCollection
Data []model.NumberRangeState `json:"data"`
}
type NumberRangeTranslationCollection ¶
type NumberRangeTranslationCollection struct {
EntityCollection
Data []model.NumberRangeTranslation `json:"data"`
}
type NumberRangeTypeCollection ¶
type NumberRangeTypeCollection struct {
EntityCollection
Data []model.NumberRangeType `json:"data"`
}
type NumberRangeTypeTranslationCollection ¶
type NumberRangeTypeTranslationCollection struct {
EntityCollection
Data []model.NumberRangeTypeTranslation `json:"data"`
}
type OAuthCredentials ¶
type OAuthCredentials interface {
GetTokenSource(ctx context.Context, tokenURL string) (oauth2.TokenSource, error)
}
OAuthCredentials is the interface for the different types of credentials
type OrderAddressCollection ¶
type OrderAddressCollection struct {
EntityCollection
Data []model.OrderAddress `json:"data"`
}
type OrderCollection ¶
type OrderCollection struct {
EntityCollection
Data []model.Order `json:"data"`
}
type OrderCustomerCollection ¶
type OrderCustomerCollection struct {
EntityCollection
Data []model.OrderCustomer `json:"data"`
}
type OrderDeliveryCollection ¶
type OrderDeliveryCollection struct {
EntityCollection
Data []model.OrderDelivery `json:"data"`
}
type OrderDeliveryPositionCollection ¶
type OrderDeliveryPositionCollection struct {
EntityCollection
Data []model.OrderDeliveryPosition `json:"data"`
}
type OrderLineItemCollection ¶
type OrderLineItemCollection struct {
EntityCollection
Data []model.OrderLineItem `json:"data"`
}
type OrderTagCollection ¶
type OrderTagCollection struct {
EntityCollection
Data []model.OrderTag `json:"data"`
}
type OrderTransactionCollection ¶
type OrderTransactionCollection struct {
EntityCollection
Data []model.OrderTransaction `json:"data"`
}
type PasswordCredentials ¶
PasswordCredentials are the credentials for the password grant type
func NewPasswordCredentials ¶
func NewPasswordCredentials(username, password string, scopes []string) PasswordCredentials
NewPasswordCredentials creates a new PasswordCredentials struct with the given parameters
func (PasswordCredentials) GetTokenSource ¶
func (c PasswordCredentials) GetTokenSource(ctx context.Context, tokenURL string) (oauth2.TokenSource, error)
GetTokenSource returns the token source for the password grant type
type PaymentMethodCollection ¶
type PaymentMethodCollection struct {
EntityCollection
Data []model.PaymentMethod `json:"data"`
}
type PaymentMethodTranslationCollection ¶
type PaymentMethodTranslationCollection struct {
EntityCollection
Data []model.PaymentMethodTranslation `json:"data"`
}
type PluginCollection ¶
type PluginCollection struct {
EntityCollection
Data []model.Plugin `json:"data"`
}
type PluginTranslationCollection ¶
type PluginTranslationCollection struct {
EntityCollection
Data []model.PluginTranslation `json:"data"`
}
type ProductCategoryCollection ¶
type ProductCategoryCollection struct {
EntityCollection
Data []model.ProductCategory `json:"data"`
}
type ProductCategoryTreeCollection ¶
type ProductCategoryTreeCollection struct {
EntityCollection
Data []model.ProductCategoryTree `json:"data"`
}
type ProductCollection ¶
type ProductCollection struct {
EntityCollection
Data []model.Product `json:"data"`
}
type ProductConfiguratorSettingCollection ¶
type ProductConfiguratorSettingCollection struct {
EntityCollection
Data []model.ProductConfiguratorSetting `json:"data"`
}
type ProductCrossSellingAssignedProductsCollection ¶
type ProductCrossSellingAssignedProductsCollection struct {
EntityCollection
Data []model.ProductCrossSellingAssignedProducts `json:"data"`
}
type ProductCrossSellingCollection ¶
type ProductCrossSellingCollection struct {
EntityCollection
Data []model.ProductCrossSelling `json:"data"`
}
type ProductCrossSellingTranslationCollection ¶
type ProductCrossSellingTranslationCollection struct {
EntityCollection
Data []model.ProductCrossSellingTranslation `json:"data"`
}
type ProductCustomFieldSetCollection ¶
type ProductCustomFieldSetCollection struct {
EntityCollection
Data []model.ProductCustomFieldSet `json:"data"`
}
type ProductExportCollection ¶
type ProductExportCollection struct {
EntityCollection
Data []model.ProductExport `json:"data"`
}
type ProductFeatureSetCollection ¶
type ProductFeatureSetCollection struct {
EntityCollection
Data []model.ProductFeatureSet `json:"data"`
}
type ProductFeatureSetTranslationCollection ¶
type ProductFeatureSetTranslationCollection struct {
EntityCollection
Data []model.ProductFeatureSetTranslation `json:"data"`
}
type ProductKeywordDictionaryCollection ¶
type ProductKeywordDictionaryCollection struct {
EntityCollection
Data []model.ProductKeywordDictionary `json:"data"`
}
type ProductManufacturerCollection ¶
type ProductManufacturerCollection struct {
EntityCollection
Data []model.ProductManufacturer `json:"data"`
}
type ProductManufacturerTranslationCollection ¶
type ProductManufacturerTranslationCollection struct {
EntityCollection
Data []model.ProductManufacturerTranslation `json:"data"`
}
type ProductMediaCollection ¶
type ProductMediaCollection struct {
EntityCollection
Data []model.ProductMedia `json:"data"`
}
type ProductOptionCollection ¶
type ProductOptionCollection struct {
EntityCollection
Data []model.ProductOption `json:"data"`
}
type ProductPriceCollection ¶
type ProductPriceCollection struct {
EntityCollection
Data []model.ProductPrice `json:"data"`
}
type ProductPropertyCollection ¶
type ProductPropertyCollection struct {
EntityCollection
Data []model.ProductProperty `json:"data"`
}
type ProductReviewCollection ¶
type ProductReviewCollection struct {
EntityCollection
Data []model.ProductReview `json:"data"`
}
type ProductSearchConfigCollection ¶
type ProductSearchConfigCollection struct {
EntityCollection
Data []model.ProductSearchConfig `json:"data"`
}
type ProductSearchConfigFieldCollection ¶
type ProductSearchConfigFieldCollection struct {
EntityCollection
Data []model.ProductSearchConfigField `json:"data"`
}
type ProductSearchKeywordCollection ¶
type ProductSearchKeywordCollection struct {
EntityCollection
Data []model.ProductSearchKeyword `json:"data"`
}
type ProductSortingCollection ¶
type ProductSortingCollection struct {
EntityCollection
Data []model.ProductSorting `json:"data"`
}
type ProductSortingTranslationCollection ¶
type ProductSortingTranslationCollection struct {
EntityCollection
Data []model.ProductSortingTranslation `json:"data"`
}
type ProductStreamCollection ¶
type ProductStreamCollection struct {
EntityCollection
Data []model.ProductStream `json:"data"`
}
type ProductStreamFilterCollection ¶
type ProductStreamFilterCollection struct {
EntityCollection
Data []model.ProductStreamFilter `json:"data"`
}
type ProductStreamMappingCollection ¶
type ProductStreamMappingCollection struct {
EntityCollection
Data []model.ProductStreamMapping `json:"data"`
}
type ProductStreamTranslationCollection ¶
type ProductStreamTranslationCollection struct {
EntityCollection
Data []model.ProductStreamTranslation `json:"data"`
}
type ProductTagCollection ¶
type ProductTagCollection struct {
EntityCollection
Data []model.ProductTag `json:"data"`
}
type ProductTranslationCollection ¶
type ProductTranslationCollection struct {
EntityCollection
Data []model.ProductTranslation `json:"data"`
}
type ProductVisibilityCollection ¶
type ProductVisibilityCollection struct {
EntityCollection
Data []model.ProductVisibility `json:"data"`
}
type PromotionCartRuleCollection ¶
type PromotionCartRuleCollection struct {
EntityCollection
Data []model.PromotionCartRule `json:"data"`
}
type PromotionCollection ¶
type PromotionCollection struct {
EntityCollection
Data []model.Promotion `json:"data"`
}
type PromotionDiscountCollection ¶
type PromotionDiscountCollection struct {
EntityCollection
Data []model.PromotionDiscount `json:"data"`
}
type PromotionDiscountPricesCollection ¶
type PromotionDiscountPricesCollection struct {
EntityCollection
Data []model.PromotionDiscountPrices `json:"data"`
}
type PromotionDiscountRuleCollection ¶
type PromotionDiscountRuleCollection struct {
EntityCollection
Data []model.PromotionDiscountRule `json:"data"`
}
type PromotionIndividualCodeCollection ¶
type PromotionIndividualCodeCollection struct {
EntityCollection
Data []model.PromotionIndividualCode `json:"data"`
}
type PromotionOrderRuleCollection ¶
type PromotionOrderRuleCollection struct {
EntityCollection
Data []model.PromotionOrderRule `json:"data"`
}
type PromotionPersonaCustomerCollection ¶
type PromotionPersonaCustomerCollection struct {
EntityCollection
Data []model.PromotionPersonaCustomer `json:"data"`
}
type PromotionPersonaRuleCollection ¶
type PromotionPersonaRuleCollection struct {
EntityCollection
Data []model.PromotionPersonaRule `json:"data"`
}
type PromotionSalesChannelCollection ¶
type PromotionSalesChannelCollection struct {
EntityCollection
Data []model.PromotionSalesChannel `json:"data"`
}
type PromotionSetgroupCollection ¶
type PromotionSetgroupCollection struct {
EntityCollection
Data []model.PromotionSetgroup `json:"data"`
}
type PromotionSetgroupRuleCollection ¶
type PromotionSetgroupRuleCollection struct {
EntityCollection
Data []model.PromotionSetgroupRule `json:"data"`
}
type PromotionTranslationCollection ¶
type PromotionTranslationCollection struct {
EntityCollection
Data []model.PromotionTranslation `json:"data"`
}
type PropertyGroupCollection ¶
type PropertyGroupCollection struct {
EntityCollection
Data []model.PropertyGroup `json:"data"`
}
type PropertyGroupOptionCollection ¶
type PropertyGroupOptionCollection struct {
EntityCollection
Data []model.PropertyGroupOption `json:"data"`
}
type PropertyGroupOptionTranslationCollection ¶
type PropertyGroupOptionTranslationCollection struct {
EntityCollection
Data []model.PropertyGroupOptionTranslation `json:"data"`
}
type PropertyGroupTranslationCollection ¶
type PropertyGroupTranslationCollection struct {
EntityCollection
Data []model.PropertyGroupTranslation `json:"data"`
}
type RuleCollection ¶
type RuleCollection struct {
EntityCollection
Data []model.Rule `json:"data"`
}
type RuleConditionCollection ¶
type RuleConditionCollection struct {
EntityCollection
Data []model.RuleCondition `json:"data"`
}
type RuleTagCollection ¶
type RuleTagCollection struct {
EntityCollection
Data []model.RuleTag `json:"data"`
}
type SEOUrlCollection ¶ added in v1.1.0
type SEOUrlCollection struct {
EntityCollection
Data []model.SeoUrl `json:"data"`
}
type SEOUrlTemplateCollection ¶ added in v1.1.0
type SEOUrlTemplateCollection struct {
EntityCollection
Data []model.SeoUrlTemplate `json:"data"`
}
type SalesChannelAnalyticsCollection ¶
type SalesChannelAnalyticsCollection struct {
EntityCollection
Data []model.SalesChannelAnalytics `json:"data"`
}
type SalesChannelCollection ¶
type SalesChannelCollection struct {
EntityCollection
Data []model.SalesChannel `json:"data"`
}
type SalesChannelCountryCollection ¶
type SalesChannelCountryCollection struct {
EntityCollection
Data []model.SalesChannelCountry `json:"data"`
}
type SalesChannelCurrencyCollection ¶
type SalesChannelCurrencyCollection struct {
EntityCollection
Data []model.SalesChannelCurrency `json:"data"`
}
type SalesChannelDomainCollection ¶
type SalesChannelDomainCollection struct {
EntityCollection
Data []model.SalesChannelDomain `json:"data"`
}
type SalesChannelLanguageCollection ¶
type SalesChannelLanguageCollection struct {
EntityCollection
Data []model.SalesChannelLanguage `json:"data"`
}
type SalesChannelPaymentMethodCollection ¶
type SalesChannelPaymentMethodCollection struct {
EntityCollection
Data []model.SalesChannelPaymentMethod `json:"data"`
}
type SalesChannelShippingMethodCollection ¶
type SalesChannelShippingMethodCollection struct {
EntityCollection
Data []model.SalesChannelShippingMethod `json:"data"`
}
type SalesChannelTranslationCollection ¶
type SalesChannelTranslationCollection struct {
EntityCollection
Data []model.SalesChannelTranslation `json:"data"`
}
type SalesChannelTypeCollection ¶
type SalesChannelTypeCollection struct {
EntityCollection
Data []model.SalesChannelType `json:"data"`
}
type SalesChannelTypeTranslationCollection ¶
type SalesChannelTypeTranslationCollection struct {
EntityCollection
Data []model.SalesChannelTypeTranslation `json:"data"`
}
type SalutationCollection ¶
type SalutationCollection struct {
EntityCollection
Data []model.Salutation `json:"data"`
}
type SalutationTranslationCollection ¶
type SalutationTranslationCollection struct {
EntityCollection
Data []model.SalutationTranslation `json:"data"`
}
type ScheduledTaskCollection ¶
type ScheduledTaskCollection struct {
EntityCollection
Data []model.ScheduledTask `json:"data"`
}
type ScriptCollection ¶
type ScriptCollection struct {
EntityCollection
Data []model.Script `json:"data"`
}
type SearchFilterType ¶
type SearchFilterType string
SearchFilterType is the type of the filter to be applied when searching.
type SearchIDsResponse ¶ added in v1.1.0
SearchIDsResponse is the response for a searchIds request
type SearchSortDirection ¶
type SearchSortDirection string
SearchSortDirection is the direction of the sort to be applied when searching.
type ShippingMethodCollection ¶
type ShippingMethodCollection struct {
EntityCollection
Data []model.ShippingMethod `json:"data"`
}
type ShippingMethodPriceCollection ¶
type ShippingMethodPriceCollection struct {
EntityCollection
Data []model.ShippingMethodPrice `json:"data"`
}
type ShippingMethodTagCollection ¶
type ShippingMethodTagCollection struct {
EntityCollection
Data []model.ShippingMethodTag `json:"data"`
}
type ShippingMethodTranslationCollection ¶
type ShippingMethodTranslationCollection struct {
EntityCollection
Data []model.ShippingMethodTranslation `json:"data"`
}
type SnippetCollection ¶
type SnippetCollection struct {
EntityCollection
Data []model.Snippet `json:"data"`
}
type SnippetSetCollection ¶
type SnippetSetCollection struct {
EntityCollection
Data []model.SnippetSet `json:"data"`
}
type StateMachineCollection ¶
type StateMachineCollection struct {
EntityCollection
Data []model.StateMachine `json:"data"`
}
type StateMachineHistoryCollection ¶
type StateMachineHistoryCollection struct {
EntityCollection
Data []model.StateMachineHistory `json:"data"`
}
type StateMachineStateCollection ¶
type StateMachineStateCollection struct {
EntityCollection
Data []model.StateMachineState `json:"data"`
}
type StateMachineStateTranslationCollection ¶
type StateMachineStateTranslationCollection struct {
EntityCollection
Data []model.StateMachineStateTranslation `json:"data"`
}
type StateMachineTransitionCollection ¶
type StateMachineTransitionCollection struct {
EntityCollection
Data []model.StateMachineTransition `json:"data"`
}
type StateMachineTranslationCollection ¶
type StateMachineTranslationCollection struct {
EntityCollection
Data []model.StateMachineTranslation `json:"data"`
}
type SyncOperation ¶
type SyncOperation struct {
Entity string `json:"entity"`
Action string `json:"action"`
Payload interface{} `json:"payload"`
}
Sync Operations for bulk request (https://shopware.stoplight.io/docs/admin-api/0612cb5d960ef-bulk-edit-entities)
type SystemConfigCollection ¶
type SystemConfigCollection struct {
EntityCollection
Data []model.SystemConfig `json:"data"`
}
type TagCollection ¶
type TagCollection struct {
EntityCollection
Data []model.Tag `json:"data"`
}
type TaxCollection ¶
type TaxCollection struct {
EntityCollection
Data []model.Tax `json:"data"`
}
type TaxRuleCollection ¶
type TaxRuleCollection struct {
EntityCollection
Data []model.TaxRule `json:"data"`
}
type TaxRuleTypeCollection ¶
type TaxRuleTypeCollection struct {
EntityCollection
Data []model.TaxRuleType `json:"data"`
}
type TaxRuleTypeTranslationCollection ¶
type TaxRuleTypeTranslationCollection struct {
EntityCollection
Data []model.TaxRuleTypeTranslation `json:"data"`
}
type ThemeChildCollection ¶
type ThemeChildCollection struct {
EntityCollection
Data []model.ThemeChild `json:"data"`
}
type ThemeCollection ¶
type ThemeCollection struct {
EntityCollection
Data []model.Theme `json:"data"`
}
type ThemeMediaCollection ¶
type ThemeMediaCollection struct {
EntityCollection
Data []model.ThemeMedia `json:"data"`
}
type ThemeSalesChannelCollection ¶
type ThemeSalesChannelCollection struct {
EntityCollection
Data []model.ThemeSalesChannel `json:"data"`
}
type ThemeTranslationCollection ¶
type ThemeTranslationCollection struct {
EntityCollection
Data []model.ThemeTranslation `json:"data"`
}
type TotalCountMode ¶
type TotalCountMode uint
TotalCountMode indicates how the total count of the search result should be calculated.
type UnitCollection ¶
type UnitCollection struct {
EntityCollection
Data []model.Unit `json:"data"`
}
type UnitTranslationCollection ¶
type UnitTranslationCollection struct {
EntityCollection
Data []model.UnitTranslation `json:"data"`
}
type UserAccessKeyCollection ¶
type UserAccessKeyCollection struct {
EntityCollection
Data []model.UserAccessKey `json:"data"`
}
type UserCollection ¶
type UserCollection struct {
EntityCollection
Data []model.User `json:"data"`
}
type UserConfigCollection ¶
type UserConfigCollection struct {
EntityCollection
Data []model.UserConfig `json:"data"`
}
type UserRecoveryCollection ¶
type UserRecoveryCollection struct {
EntityCollection
Data []model.UserRecovery `json:"data"`
}
type VersionCollection ¶
type VersionCollection struct {
EntityCollection
Data []model.Version `json:"data"`
}
type VersionCommitCollection ¶
type VersionCommitCollection struct {
EntityCollection
Data []model.VersionCommit `json:"data"`
}
type VersionCommitDataCollection ¶
type VersionCommitDataCollection struct {
EntityCollection
Data []model.VersionCommitData `json:"data"`
}
type WebhookCollection ¶
type WebhookCollection struct {
EntityCollection
Data []model.Webhook `json:"data"`
}
type WebhookEventLogCollection ¶
type WebhookEventLogCollection struct {
EntityCollection
Data []model.WebhookEventLog `json:"data"`
}